@@ -640,8 +640,12 @@ class PhotoSet(TendenciBaseModel):
         user = user or AnonymousUser()
 
         filters = get_query_filters(user, 'photos.view_image')
+
         photos = Image.objects.filter(filters).filter(photoset=self.pk)
 
+        if user.is_authenticated():
+            photos = photos.distinct()
+
         return photos
 
     def delete_all_images(self):
