@@ -1,6 +1,7 @@
 import re
 
 from django import forms
+from django.conf import settings
 from django.contrib.auth.models import User
 from django.contrib.auth.forms import SetPasswordForm
 from django.contrib.auth import authenticate, login
@@ -231,6 +232,6 @@ class PasswordResetForm(forms.Form):
             'protocol': use_https and 'https' or 'http',
         }
 
-        from_email = get_setting('site', 'global', 'siteemailnoreplyaddress')
+        from_email = get_setting('site', 'global', 'siteemailnoreplyaddress') or settings.DEFAULT_FROM_EMAIL
         send_mail(_("Password reset on %s") % site_name,
             t.render(Context(c)), from_email, [user.email])
