@@ -62,7 +62,7 @@ def navigation(context, nav_id):
     return context
 
 @register.inclusion_tag("navs/load_nav.html", takes_context=True)
-def load_nav(context, nav_id):
+def load_nav(context, nav_id, show_title=False):
     """
     Renders the nav and its nav items.
     This will call nav_item that will call itself recursively nesting 
@@ -76,6 +76,7 @@ def load_nav(context, nav_id):
     context.update({
         "nav": nav,
         "items": nav.top_items,
+        "show_title": show_title,
     })
     return context
 
@@ -90,7 +91,8 @@ def nav_item(context, item):
     return context
 
 @register.inclusion_tag("navs/cached_nav.html", takes_context=True)
-def nav(context, nav_id):
+def nav(context, nav_id, show_title=False):
+    
     """
     Renders the nav from cache
     if not will use the navigation tag for rendering the nav
@@ -117,13 +119,14 @@ def nav(context, nav_id):
         nav_object = navs[0]
         nav = get_nav(nav_object.pk)
         if not nav:
-            cache_nav(nav_object)
+            cache_nav(nav_object, show_title)
     except:
         return None
 
     context.update({
         "cached": nav,
         "nav_id": nav_id,
+        "show_title": show_title,
     })
     return context
 
