@@ -556,7 +556,7 @@ def swfupload(request):
 
         try:
             file = form.save(commit=False)
-            file.name = re.sub(r'[^a-z0-9._]+', '_', file.file.name.lower())
+            file.name = re.sub(r'[^a-zA-Z0-9._-]+', '_', file.file.name)
             file.object_id = object_id
             file.content_type = ContentType.objects.get(app_label=app_label, model=model)
             file.owner = request.user
