@@ -121,7 +121,7 @@ class Person(TendenciBaseModel):
         state_zip = ' '.join([s for s in (self.state, self.zipcode) if s])
         city_state_zip = ', '.join([s for s in (self.city, state_zip, self.country) if s])
 
-        return '%s %s' % (self.address, city_state_zip)
+        return '%s %s %s' % (self.address, self.address2, city_state_zip)
 
 
 class Address(models.Model):
